# Generated by ariadne-codegen
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import AutoRechargeSettingsFragment


class SaveAutomaticRechargeConfiguration(BaseModel):
    save_auto_recharge_settings: "SaveAutomaticRechargeConfigurationSaveAutoRechargeSettings" = Field(
        alias="saveAutoRechargeSettings"
    )


class SaveAutomaticRechargeConfigurationSaveAutoRechargeSettings(
    AutoRechargeSettingsFragment
):
    pass


SaveAutomaticRechargeConfiguration.model_rebuild()
