# Generated by ariadne-codegen
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SubscriptionFragment


class GetSubscription(BaseModel):
    get_subscription: "GetSubscriptionGetSubscription" = Field(alias="getSubscription")


class GetSubscriptionGetSubscription(SubscriptionFragment):
    pass


GetSubscription.model_rebuild()
